==> root-6.16.00-4-x86_64.pkg.tar.xz: usr/include/root/RConfigure.h <==
#ifndef ROOT_RConfigure
#define ROOT_RConfigure

/* Configurations file for linuxx8664gcc */
#ifdef R__HAVE_CONFIG
#define ROOTPREFIX    "/usr"
#define ROOTBINDIR    "/usr/bin"
#define ROOTLIBDIR    "/usr/lib/root"
#define ROOTINCDIR    "/usr/include/root"
#define ROOTETCDIR    "/etc/root"
#define ROOTDATADIR   "/usr/share/root"
#define ROOTDOCDIR    "/usr/share/doc/root"
#define ROOTMACRODIR  "/usr/share/root/macros"
#define ROOTTUTDIR    "/usr/share/doc/root/tutorials"
#define ROOTSRCDIR    "/usr/share/root/src"
#define ROOTICONPATH  "/usr/share/root/icons"
#define TTFFONTDIR    "/usr/share/root/fonts"
#endif

#define EXTRAICONPATH ""

#define R__HAS_SETRESUID   /**/
#define R__HAS_MATHMORE   /**/
#define R__HAS_PTHREAD    /**/
#define R__HAS_XFT    /**/
#undef R__HAS_COCOA    /**/
#define R__HAS_VC    /**/
#define R__HAS_VDT    /**/
#undef R__HAS_VECCORE    /**/
#undef R__USE_CXX11    /**/
#undef R__USE_CXX14    /**/
#define R__USE_CXX17    /**/
#undef R__USE_CXXMODULES   /**/
#undef R__USE_LIBCXX    /**/
#define R__HAS_STD_STRING_VIEW   /**/
#undef R__HAS_STD_EXPERIMENTAL_STRING_VIEW   /**/
#undef R__HAS_STOD_STRING_VIEW /**/
#define R__HAS_STD_APPLY /**/
#define R__HAS_STD_INVOKE /**/
#define R__HAS_STD_INDEX_SEQUENCE /**/
#define R__HAS_ATTRIBUTE_ALWAYS_INLINE /**/
#undef R__EXTERN_LLVMDIR /**/
#define R__USE_IMT   /**/
#undef R__COMPLETE_MEM_TERMINATION /**/
#undef R__HAS_CEFWEB  /**/
#undef R__HAS_QT5WEB  /**/
#undef R__HAS_DAVIX  /**/

#if defined(R__HAS_VECCORE) && defined(R__HAS_VC)
#ifndef VECCORE_ENABLE_VC
#define VECCORE_ENABLE_VC
#endif
#endif

#undef R__HAS_DEFAULT_LZ4  /**/
#define R__HAS_DEFAULT_ZLIB  /**/
#undef R__HAS_DEFAULT_LZMA  /**/

#define R__HAS_TMVACPU /**/
#undef R__HAS_TMVAGPU /**/

#endif

==> root-6.18.04-1-x86_64.pkg.tar.xz: usr/include/root/RConfigure.h <==
#ifndef ROOT_RConfigure
#define ROOT_RConfigure

/* Configurations file for linuxx8664gcc */
#ifdef R__HAVE_CONFIG
#define ROOTPREFIX    "/usr"
#define ROOTBINDIR    "/usr/bin"
#define ROOTLIBDIR    "/usr/lib/root"
#define ROOTINCDIR    "/usr/include/root"
#define ROOTETCDIR    "/etc/root"
#define ROOTDATADIR   "/usr/share/root"
#define ROOTDOCDIR    "/usr/share/doc/root"
#define ROOTMACRODIR  "/usr/share/root/macros"
#define ROOTTUTDIR    "/usr/share/doc/root/tutorials"
#define ROOTSRCDIR    "/usr/share/root/src"
#define ROOTICONPATH  "/usr/share/root/icons"
#define TTFFONTDIR    "/usr/share/root/fonts"
#endif

#define EXTRAICONPATH ""

#define R__HAS_SETRESUID   /**/
#define R__HAS_MATHMORE   /**/
#define R__HAS_PTHREAD    /**/
#define R__HAS_XFT    /**/
#undef R__HAS_COCOA    /**/
#define R__HAS_VC    /**/
#define R__HAS_VDT    /**/
#undef R__HAS_VECCORE    /**/
#define R__USE_CXXMODULES   /**/
#undef R__USE_LIBCXX    /**/
#define R__HAS_STD_STRING_VIEW   /**/
#undef R__HAS_STD_EXPERIMENTAL_STRING_VIEW   /**/
#undef R__HAS_STOD_STRING_VIEW /**/
#define R__HAS_STD_APPLY /**/
#define R__HAS_STD_INVOKE /**/
#define R__HAS_STD_INDEX_SEQUENCE /**/
#define R__HAS_ATTRIBUTE_ALWAYS_INLINE /**/
#define R__HAS_ATTRIBUTE_NOINLINE /**/
#undef R__EXTERN_LLVMDIR /**/
#define R__USE_IMT   /**/
#undef R__COMPLETE_MEM_TERMINATION /**/
#undef R__HAS_CEFWEB  /**/
#undef R__HAS_QT5WEB  /**/
#undef R__HAS_DAVIX  /**/

#if defined(R__HAS_VECCORE) && defined(R__HAS_VC)
#ifndef VECCORE_ENABLE_VC
#define VECCORE_ENABLE_VC
#endif
#endif

#undef R__HAS_DEFAULT_LZ4  /**/
#define R__HAS_DEFAULT_ZLIB  /**/
#undef R__HAS_DEFAULT_LZMA  /**/
#undef R__HAS_CLOUDFLARE_ZLIB /**/

#define R__HAS_TMVACPU /**/
#undef R__HAS_TMVAGPU /**/


#endif
